Rect

Struct Rect 

pub struct Rect { /* private fields */ }

Implementations

Source

impl Rect

pub fn try_downcast(element: &(dyn ElementExt + 'static)) -> Option<RectElement>

pub fn color(self, color: impl Into<Fill>) -> Rect

Set the fill of text rendered inside the rect and inherited by its children. See Fill.

pub fn font_size(self, font_size: impl Into<FontSize>) -> Rect

Set the size of text rendered inside the rect and inherited by its children. See FontSize.

pub fn overflow<S>(self, overflow: S) -> Rect
where S: Into<Overflow>,

Set whether content overflowing the rect’s bounds is clipped. See Overflow.

pub fn rotate<R>(self, rotation: R) -> Rect
where R: Into<Option<f32>>,

Rotate the rect by the given angle in degrees.

pub fn scale(self, scale: impl Into<Scale>) -> Rect

Scale the rect. See Scale.

pub fn transform_origin( self, transform_origin: impl Into<TransformOrigin>, ) -> Rect

Set the point that the scale and rotation effects pivot around.

Defaults to the element’s center.

pub fn opacity(self, opacity: f32) -> Rect

Set the rect’s opacity, from 0.0 (transparent) to 1.0 (opaque).

pub fn blur(self, blur: f32) -> Rect

Apply a gaussian blur of the given radius to the rect.